@@ -1,6 +1,6 @@
 package Bio::Graphics::Browser2::Session;
 
-# $Id: Session.pm 22257 2009-11-16 15:11:04Z lstein $
+# $Id: Session.pm 22514 2010-01-10 02:29:36Z lstein $
 
 use strict;
 use warnings;
@@ -257,7 +257,7 @@ sub using_openid {
 sub set_nonce {
     my $self = shift;
     my ($nonce,$salt,$remember) = @_;
-    warn "id=",$self->id," writing nonce = ",md5_hex($nonce,$salt);
+    warn "id=",$self->id," writing nonce = ",md5_hex($nonce,$salt) if DEBUG;
     $self->{session}->param('.nonce' => md5_hex($nonce,$salt));
 
     # BUG: must handle session expiration
@@ -274,8 +274,8 @@ sub match_nonce {
     my ($new_nonce,$salt) = @_;
     $self->private || return;
     my $nonce = $self->{session}->param('.nonce');
-    warn "id=",$self->id," matching $nonce against ",$new_nonce,"|",$salt;
-    warn "$nonce eq ",md5_hex($new_nonce,$salt);
+    warn "id=",$self->id," matching $nonce against ",$new_nonce,"|",$salt if DEBUG;
+    warn "$nonce eq ",md5_hex($new_nonce,$salt)                           if DEBUG;
     return $nonce eq md5_hex($new_nonce,$salt);
 }
 
